==> lxqt-powermanagement-2.2.0.tar.xz: lxqt-powermanagement-2.2.0/config/translations/lxqt-config-powermanagement_ka.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>ელემენტის მონიტორინგის მორგება</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>ელემე&amp;ნტის მონიტორინგის ჩართვა</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>გაფრთხილება:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> წამი</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>დონე დაბალია:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>ხატულა:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>მინიატურა</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>იტენება</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>იცლება</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>რა მოხდება, როცა მუხტი დაბალია:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>ხატულას ჩვენება:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>თემიდან</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>წრე</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>წრე პროცენტებით</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>ელემენტი პროცენტებით და ფონი</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>ელემენტი პროცენტებით</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>ჩაშენებული</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>დონე: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>უქმეობის მონიტორინ&amp;გის ჩართვა</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>უქმეობის დრო:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>უკუგანათების ცვლილების ჩართვა</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>როცა უქმეა, ელემენტზე:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation>ელემენტის უქმეობის დრო:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>უკუგანათება (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>წთ:წმ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>წთ:წმ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>როცა უქმეა კვებით:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>შეერთებული უქმეობის დრო:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>წუთი:წამი (წუთი:01:30)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation>უკუგანათების შემოწმება</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation>მუშაობს ელემენტზე </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>უქმეობის შემოწმების გათიშვა სრულ ეკრანზე</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>ნოუთბუქის დახურვის მონიტორინგის ჩართვ&amp;ა</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>ქმედება, როცა ნოუთბუქს დახურავენ:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>ელემენტზე:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>ძილი</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>პროგრამული ძილი</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>გამორთვა</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>შეერთებული:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>&amp;გარე ეკრანის გამოყენებისას</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>კვების მართვის მორგება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>ელემენტი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>თავსახური</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>უმოქმედო</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>კვების ღილაკები</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>ფორმა</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>კვების ღილაკების მართვა</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>კვების ღილაკის ქმედება:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>შეჩერების ღილაკის ქმედება:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>პროგრამული ძილის ღილაკის ქმედება:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.cpp" line="48"/>
        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
        <translation>შენიშვნა: Wayland-ში კვების ღილაკებს კომპოზიტორი მართავს.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Ask</source>
        <translation>კითხვა</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Lock screen</source>
        <translation>ეკრანის დაბლოკვა</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Suspend</source>
        <translation>ძილი</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="42"/>
        <source>Hibernate</source>
        <translation>პროგრამული ძილი</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="43"/>
        <source>Shutdown</source>
        <translation>გამორთვა</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="44"/>
        <source>Turn Off monitor(s)</source>
        <translation>ეკრან(ებ)-ის გამორთვა</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_2.3.0.orig.tar.xz: lxqt-powermanagement-2.3.0/config/translations/lxqt-config-powermanagement_ka.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>ელემენტის მონიტორინგის მორგება</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>ელემე&amp;ნტის მონიტორინგის ჩართვა</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>გაფრთხილება:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> წამი</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>დონე დაბალია:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>ხატულა:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Preview</source>
        <translation>მინიატურა</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>იტენება</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>იცლება</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>რა მოხდება, როცა მუხტი დაბალია:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>ხატულას ჩვენება:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>თემიდან</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>წრე</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>წრე პროცენტებით</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>ელემენტი პროცენტებით და ფონი</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>ელემენტი პროცენტებით</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>built in</source>
        <translation>ჩაშენებული</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="114"/>
        <source>Level: %1%</source>
        <translation>დონე: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>უქმეობის მონიტორინ&amp;გის ჩართვა</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>უქმეობის დრო:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>უკუგანათების ცვლილების ჩართვა</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>როცა უქმეა, ელემენტზე:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="93"/>
        <source>Battery Idle time:</source>
        <translation>ელემენტის უქმეობის დრო:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>უკუგანათება (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>წთ:წმ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="113"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>წთ:წმ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>როცა უქმეა კვებით:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>შეერთებული უქმეობის დრო:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="100"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>წუთი:წამი (წუთი:01:30)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="195"/>
        <source>Check backlight</source>
        <translation>უკუგანათების შემოწმება</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>On battery discharging </source>
        <translation>მუშაობს ელემენტზე </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Command to Turn off Monitor</source>
        <translation>ბრძანება ეკრანის გამოსართავად</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="214"/>
        <source>Recommended command for:</source>
        <translation>რეკომენდებული ბრძანება:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="234"/>
        <source>On Wayland, usually handled by compositor and app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="237"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>უქმეობის შემოწმების გათიშვა სრულ ეკრანზე</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>ნოუთბუქის დახურვის მონიტორინგის ჩართვ&amp;ა</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>ქმედება, როცა ნოუთბუქს დახურავენ:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>ელემენტზე:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>ძილი</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>პროგრამული ძილი</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>გამორთვა</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>შეერთებული:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>&amp;გარე ეკრანის გამოყენებისას</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>კვების მართვის მორგება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Battery</source>
        <translation>ელემენტი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="50"/>
        <source>Lid</source>
        <translation>თავსახური</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="57"/>
        <source>Idle</source>
        <translation>უმოქმედო</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="64"/>
        <source>Power keys</source>
        <translation>კვების ღილაკები</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>ფორმა</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>კვების ღილაკების მართვა</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>კვების ღილაკის ქმედება:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>შეჩერების ღილაკის ქმედება:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>პროგრამული ძილის ღილაკის ქმედება:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.cpp" line="50"/>
        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
        <translation>შენიშვნა: Wayland-ში კვების ღილაკებს კომპოზიტორი მართავს.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Ask</source>
        <translation>კითხვა</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Lock screen</source>
        <translation>ეკრანის დაბლოკვა</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Suspend</source>
        <translation>ძილი</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="42"/>
        <source>Hibernate</source>
        <translation>პროგრამული ძილი</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="43"/>
        <source>Shutdown</source>
        <translation>გამორთვა</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="44"/>
        <source>Turn Off monitor(s)</source>
        <translation>ეკრან(ებ)-ის გამორთვა</translation>
    </message>
</context>
</TS>
